Page 91 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 91

Home

    — this drift is going to continue. It's going to continue
    unless Congress changes it, and that means Congress has
    to be changed. What we're talking about is virtually a
    revolution in the awareness of the American people."

    For a deeper understanding of the conspiratorial
    forces behind the creation of the Federal Reserve, we

    From Jekyll Island. . . A Second Look at the Federal
    Reserve. It is available from, American Media, P. O. Box
    4646, Westlake Village, California.

    The great question is, How has it happened that the
    American people now find themselves on the verge of
    losing their independence, and freedom, to a one world
    government? To answer this question we must examine
    a chronology of events occurring on the secret side of
    history during the 20th century.

    In 1954 the United States Congress created a special
    committee to investigate tax-free foundations. This

    nm

    committee was known as the Reece Committee, in
    recognition of its chairman, Congressman Carroll Reece
    of Tennessee.

    In 1982, G. Edward Griffin interviewed Norman
    Dodd, staff director of the Reece Committee. Here, in
    Norman Dodd's own words, is some of the shocking
    information discovered in the minutes of the Carnegie

    ce aa

    We are at the year 1908, which was the year that the
    Carnegie began operations, and in that year, the trustees,

    86

    The Secret Side of History

    recommend G. Edward Griffin's book The Creature

    Endowment for International Peace: